/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTDEVICES_H_
#define FANCYSPSDCLIENTDEVICES_H_

#include <fancygpsdclientmessage.h>
#include <fancygpsdclientdevice.h>
#include <fancylist.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
Name	Always?	Type	Description
class	Yes	string	Fixed: "DEVICES"
devices	Yes	list	List of device descriptions
remote	No	string	URL of the remote daemon reporting the device set. If empty, this is a DEVICES response from the local daemon.

 * </pre>
 */
class FANCYGPSDCLIENT_API Devices : public Message
 {

	Fancy::ObjPtr<Fancy::List> devicelist;

 public:

 typedef Fancy::ObjPtr<Devices> ptr_t;
 static ptr_t newInstance();
 static Fancy::Serializable::ptr_t newSerializableInstance();
 static const char* getSerialID_s();
 static const char* getSuperSerialID_s();
 const char* getSerialID() const;
 const char* getSuperSerialID() const;

 void writeFields(const ObjPtr<Serializer>& serializer) const;
 ObjPtr<Serializable> readFields(const ObjPtr<Serializer>& serializer, int64_t serialVersionUID);


 void setDeviceList(Fancy::ObjPtr<Fancy::List> devicelist);
 Fancy::ObjPtr<Fancy::List> getDeviceList() const;


 protected:
 Devices();
 virtual ~Devices();
 };

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
