/***********************************************************
 * $Id$
 *
 * FancyLibs GPSD Client
 *
 * Copyright (C) 2014 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSPSDCLIENTVERSION_H_
#define FANCYSPSDCLIENTVERSION_H_

#include <fancygpsdclientmessage.h>
#include <fancystring.h>

namespace Fancy {
namespace GpsdClient {

/**
 * <pre>
 Name	Always?	Type	Description
class	Yes	string	Fixed: "VERSION"
release	Yes	string	Public release level
rev	Yes	string	Internal revision-control level.
proto_major	Yes	numeric	API major revision level.
proto_minor	Yes	numeric	API minor revision level.
remote	No	string	URL of the remote daemon reporting this version. If empty, this is the version of the local daemon.

 * </pre>
 */
class FANCYGPSDCLIENT_API Version : public Message {

	Fancy::String::ptr_t release;
	Fancy::String::ptr_t rev;
	int32_t proto_major;
	int32_t proto_minor;

public:
	typedef Fancy::ObjPtr<Version> ptr_t;

	static ptr_t newInstance();
	static Fancy::Serializable::ptr_t newSerializableInstance();

	static const char *getSerialID_s();
	static const char *getSuperSerialID_s();
	const char *getSerialID() const;
	const char *getSuperSerialID() const;

	void writeFields(const ObjPtr<Serializer> &serializer) const;
	ObjPtr<Serializable> readFields(const ObjPtr<Serializer> &serializer, int64_t serialVersionUID);

	int32_t getProtoMajor() const;
	void setProtoMajor(int32_t protoMajor);
	int32_t getProtoMinor() const;
	void setProtoMinor(int32_t protoMinor);
	const Fancy::String::ptr_t& getRelease() const;
	void setRelease(const Fancy::String::ptr_t& release);
	const Fancy::String::ptr_t& getRev() const;
	void setRev(const Fancy::String::ptr_t& rev);

protected:
	Version();
	virtual ~Version();
};

} /* namespace GpsdClient */
} /* namespace Fancy */

#endif /* FANCYSPSDCLIENTVERSION_H_ */
